@@ -1,4 +1,4 @@
-"""Module to interface with CodeOcean's backend.
+"""Module to interface with Code Ocean's backend.
 """
 from typing import Dict, List, Optional
 
@@ -6,19 +6,19 @@ import requests
 
 
 class CodeOceanClient:
-    """Client that will connect to CodeOcean"""
+    """Client that will connect to Code Ocean"""
 
     def __init__(self, domain: str, token: str, api_version: int = 1) -> None:
         """
-        Base client for CodeOcean's API
+        Base client for Code Ocean's API
         Parameters
         ----------
         domain : str
-          VPC domain
+            VPC domain
         token : str
-          API token
+            API token
         api_version : int
-          CodeOcean API version
+            Code Ocean API version
         """
         self.domain = domain
         self.token = token
@@ -31,7 +31,7 @@ class CodeOceanClient:
 
     def get_data_asset(self, data_asset_id: str) -> requests.models.Response:
         """
-        This will get data from a GET request to code ocean API.
+        This will get data from a GET request to Code Ocean API.
 
         Parameters
         ---------------
@@ -47,6 +47,60 @@ class CodeOceanClient:
         response = requests.get(url, auth=(self.token, ""))
         return response
 
+    def search_data_assets(
+        self,
+        start: Optional[int] = None,
+        limit: Optional[int] = None,
+        sort_order: Optional[str] = None,
+        sort_field: Optional[str] = None,
+        type: Optional[str] = None,
+        ownership: Optional[str] = None,
+        favorite: Optional[bool] = None,
+        archived: Optional[bool] = None,
+        query: Optional[str] = None,
+    ) -> requests.models.Response:
+        """
+        This will return data assets from a GET requets to Code Ocean API.
+
+        Parameters
+        ---------------
+        start : Optional[int]
+            Describes the search from index.
+        limit : Optional[int]
+            Describes the upper limit to search.
+        sort_order : Optional[str]
+            Determines the result sort order.
+        sort_field : Optional[str]
+            Determines the field to sort by.
+        type : Optional[str]
+            Type of data asset: dataset or result.
+            Returns both if omitted.
+        ownership : Optional[str]
+            Search data asset by ownership: owner or shared.
+        favorite : Optional[bool]
+            Search only favorite data assets.
+        archived : Optional[bool]
+            Search only archived data assets.
+        query : Optional[str]
+            Determines the search query.
+
+        Returns
+        ---------------
+        requests.models.Response
+        """
+        optional_params = locals()
+        query_params = {}
+
+        for param, val in optional_params.items():
+            if val is not None:
+                query_params[param] = val
+
+        response = requests.get(
+            self.asset_url, params=query_params, auth=(self.token, "")
+        )
+
+        return response
+
     def register_data_asset(
         self,
         asset_name: str,
@@ -116,6 +170,57 @@ class CodeOceanClient:
         )
         return response
 
+    def register_result_as_data_asset(
+        self,
+        computation_id: str,
+        asset_name: str,
+        asset_description: Optional[str] = "",
+        mount: Optional[str] = None,
+        tags: Optional[List] = None,
+    ) -> requests.models.Response:
+        """
+        Parameters
+        ---------------
+        computation_id : string
+            Computation id
+        asset_name : string
+            Name of the data asset.
+        asset_description : Optional[str]
+            A description of the data asset. Default blanks.
+        mount : string
+            Mount point. Default None (Mount point equal to the asset name)
+        tags : Optional[List[str]]
+            A list of tags to attach to the data asset.
+            Default None (empty list).
+
+        keep_on_external_storage : Optional[bool]
+            Keep data asset on external storage. Defaults to True.
+        index_data : Optional[bool]
+            Whether to index the data asset. Defaults to True.
+        Returns
+        ---------------
+        requests.models.Response
+        """
+
+        tags_to_attach = [] if tags is None else tags
+
+        if mount is None:
+            mount = asset_name
+
+        json_data = {
+            "name": asset_name,
+            "description": asset_description,
+            "mount": mount,
+            "tags": tags_to_attach,
+            "source": {"computation": {"id": computation_id}},
+        }
+
+        response = requests.post(
+            self.asset_url, json=json_data, auth=(self.token, "")
+        )
+
+        return response
+
     def update_data_asset(
         self,
         data_asset_id: str,
@@ -125,7 +230,7 @@ class CodeOceanClient:
         new_mount: Optional[str] = None,
     ) -> requests.models.Response:
         """
-        This will update a data asset from a PUT request to code ocean API.
+        This will update a data asset from a PUT request to Code Ocean API.
 
         Parameters
         ---------------
@@ -167,7 +272,7 @@ class CodeOceanClient:
         parameters: Optional[List] = None,
     ) -> requests.models.Response:
         """
-        This will run a capsule/pipeline using a POST request to code ocean
+        This will run a capsule/pipeline using a POST request to Code Ocean
         API.
 
         Parameters
@@ -181,20 +286,15 @@ class CodeOceanClient:
         parameters : List
             Parameters given to the capsule. Default None which means
             the capsule runs with no parameters.
-
             The parameters should match in order to the parameters given in the
-            capsule.
-
-            e.g.
+            capsule, e.g.
             'parameters': [
-                'input_folder',
-                'output_folder',
-                'bucket_name'
+            'input_folder',
+            'output_folder',
+            'bucket_name'
             ]
-
             where position one refers to the parameter #1 ('input_folder'),
             parameter #2 ('output_folder'), and parameter #3 ('bucket_name')
-
         Returns
         ---------------
         requests.models.Response
@@ -213,7 +313,7 @@ class CodeOceanClient:
 
     def get_capsule(self, capsule_id: str) -> requests.models.Response:
         """
-        This will get metadata from a GET request to code ocean API.
+        This will get metadata from a GET request to Code Ocean API.
 
         Parameters
         ---------------
@@ -233,7 +333,7 @@ class CodeOceanClient:
         self, capsule_id: str
     ) -> requests.models.Response:
         """
-        This will get computation's metadata from a GET request to codeocean
+        This will get computation's metadata from a GET request to Code Ocean
         API.
 
         Parameters
@@ -252,7 +352,7 @@ class CodeOceanClient:
 
     def get_computation(self, computation_id: str) -> requests.models.Response:
         """
-        This will get metadata from a GET request to code ocean API.
+        This will get metadata from a GET request to Code Ocean API.
 
         Parameters
         ---------------
@@ -273,7 +373,7 @@ class CodeOceanClient:
     ) -> requests.models.Response:
         """
         This will get a list of the computation's metadata from a POST request
-        to code ocean API.
+        to Code Ocean API.
 
         Parameters
         ---------------
@@ -294,7 +394,7 @@ class CodeOceanClient:
     ) -> requests.models.Response:
         """
         This will get download link for a file from a GET request to
-        codeocean API.
+        Code Ocean API.
 
         Parameters
         ---------------
@@ -302,7 +402,7 @@ class CodeOceanClient:
             ID of the computation
 
         path_to_file : string
-            Path of the file under /results folder in code ocean capsule
+            Path of the file under /results folder in Code Ocean capsule
 
         Returns
         ---------------
